@@ -23,6 +23,7 @@
 
 #include <QObject>
 #include <QDBusVirtualObject>
+#include <QDBusContext>
 
 #include "access.h"
 #include "appchooser.h"
@@ -33,10 +34,13 @@
 #include "print.h"
 #if SCREENCAST_ENABLED
 #include "screencast.h"
+#include "remotedesktop.h"
+#include "waylandintegration.h"
 #endif
 #include "screenshot.h"
+#include "settings.h"
 
-class DesktopPortal : public QObject
+class DesktopPortal : public QObject, public QDBusContext
 {
     Q_OBJECT
 public:
@@ -53,8 +57,10 @@ private:
     PrintPortal *m_print;
 #if SCREENCAST_ENABLED
     ScreenCastPortal *m_screenCast;
+    RemoteDesktopPortal *m_remoteDesktop;
 #endif
     ScreenshotPortal *m_screenshot;
+    SettingsPortal *m_settings;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_DESKTOP_PORTAL_H
