@@ -20,50 +20,50 @@
 
 #include "screenchooserdialog.h"
 #include "ui_screenchooserdialog.h"
-#include "screencast.h"
 
-#include <QLoggingCategory>
-#include <QSettings>
-#include <QStandardPaths>
+#include <KLocalizedString>
 #include <QPushButton>
+#include <QStandardPaths>
+#include <QSettings>
 
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeScreenChooserDialog, "xdp-kde-screen-chooser-dialog")
-
-ScreenChooserDialog::ScreenChooserDialog(const QMap<quint32, ScreenCastPortalOutput> &screens, bool multiple, QDialog *parent, Qt::WindowFlags flags)
+ScreenChooserDialog::ScreenChooserDialog(const QString &appName, bool multiple, QDialog *parent, Qt::WindowFlags flags)
     : QDialog(parent, flags)
     , m_dialog(new Ui::ScreenChooserDialog)
 {
     m_dialog->setupUi(this);
 
-    QMapIterator<quint32, ScreenCastPortalOutput> it(screens);
-    while (it.hasNext()) {
-        it.next();
-        QListWidgetItem *widgetItem = new QListWidgetItem(m_dialog->screenView);
-        widgetItem->setData(Qt::UserRole, it.key());
-        if (it.value().outputType == ScreenCastPortalOutput::Laptop) {
-            widgetItem->setIcon(QIcon::fromTheme("computer-laptop"));
-            widgetItem->setText(i18n("Laptop screen\nModel: %1", it.value().model));
-        } else if (it.value().outputType == ScreenCastPortalOutput::Monitor) {
-            widgetItem->setIcon(QIcon::fromTheme("video-display"));
-            widgetItem->setText(i18n("Manufacturer: %1\nModel: %2", it.value().manufacturer, it.value().model));
-        } else {
-            widgetItem->setIcon(QIcon::fromTheme("video-television"));
-            widgetItem->setText(i18n("Manufacturer: %1\nModel: %2", it.value().manufacturer, it.value().model));
-        }
+    if (multiple) {
+        m_dialog->screenView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     }
 
-    m_dialog->screenView->setItemSelected(m_dialog->screenView->itemAt(0, 0), true);
-
     connect(m_dialog->buttonBox, &QDialogButtonBox::accepted, this, &ScreenChooserDialog::accept);
     connect(m_dialog->buttonBox, &QDialogButtonBox::rejected, this, &ScreenChooserDialog::reject);
     connect(m_dialog->screenView, &QListWidget::itemDoubleClicked, this, &ScreenChooserDialog::accept);
 
-    if (multiple) {
-        m_dialog->screenView->setSelectionMode(QAbstractItemView::ExtendedSelection);
+    m_dialog->buttonBox->button(QDialogButtonBox::Ok)->setText(i18n("Share"));
+
+    QString applicationName;
+    const QString desktopFile = appName + QLatin1String(".desktop");
+    const QStringList desktopFileLocations = QStandardPaths::locateAll(QStandardPaths::ApplicationsLocation, desktopFile, QStandardPaths::LocateFile);
+    for (const QString &location : desktopFileLocations) {
+        QSettings settings(location, QSettings::IniFormat);
+        settings.beginGroup(QStringLiteral("Desktop Entry"));
+        if (settings.contains(QStringLiteral("X-GNOME-FullName"))) {
+            applicationName = settings.value(QStringLiteral("X-GNOME-FullName")).toString();
+        } else {
+            applicationName = settings.value(QStringLiteral("Name")).toString();
+        }
+
+        if (!applicationName.isEmpty()) {
+            break;
+        }
     }
 
-    m_dialog->buttonBox->button(QDialogButtonBox::Ok)->setText(i18n("Share"));
-    setWindowTitle(i18n("Select screen to share"));
+    if (applicationName.isEmpty()) {
+        setWindowTitle(i18n("Select screen to share with the requesting application"));
+    } else {
+        setWindowTitle(i18n("Select screen to share with %1").arg(applicationName));
+    }
 }
 
 ScreenChooserDialog::~ScreenChooserDialog()
@@ -73,11 +73,5 @@ ScreenChooserDialog::~ScreenChooserDialog()
 
 QList<quint32> ScreenChooserDialog::selectedScreens() const
 {
-    QList<quint32> selectedScreens;
-
-    foreach (QListWidgetItem *item, m_dialog->screenView->selectedItems()) {
-        selectedScreens << item->data(Qt::UserRole).toUInt();
-    }
-
-    return selectedScreens;
+    return m_dialog->screenView->selectedScreens();
 }
